@@ -956,7 +956,8 @@ class Node(Base):
             tx = Transaction.get_transaction(kwargs.get("tx", None))
             create_relationship_url = self._dic["create_relationship"]
             # Check if target node doesn't exist yet
-            if isinstance(to, TransactionOperationProxy):
+            if (isinstance(to, TransactionOperationProxy)
+                and not isinstance(to, Node)):
                 to_url = "{%s}" % to()["id"]
             else:
                 to_url = to.url
@@ -1360,7 +1361,9 @@ class Index(object):
             else:
                 url_ref = item
             request_url_and_key = self.url.rsplit('/', 1)  # assumes a key
-            data = {"key": request_url_and_key[1],
+            # It's URL encoded and we need Unicode
+            key = urllib.unquote(str(request_url_and_key[1])).decode("utf8")
+            data = {"key": key,
                     "value": value,  # smart_quote is not needed anymore
                     "uri": url_ref}
             if tx:
