@@ -284,6 +284,21 @@ class IndexesTestCase(RelationshipsTestCase):
         self.assertTrue(n1 in index["age"][30])
         self.assertTrue(n1 in index["mean"][2.7])
 
+    def test_create_index_for_nodes_and_unicode(self):
+        index = self.gdb.nodes.indexes.create(name="unicode")
+        n1 = self.gdb.nodes.create(name="First")
+        key = u"Profesión"
+        value = u"Înformáticö"
+        n1.set(key, value)
+        index[key][value] = n1
+        self.assertTrue(n1 in index[key][value])
+        n2 = self.gdb.nodes.create(name="Second")
+        key = u"Título/Nombre"
+        value = u"Necronomicón"
+        n2.set(key, value)
+        index[key][value] = n2
+        self.assertTrue(n2 in index[key][value])
+
     def test_create_index_for_nodes_url_safe(self):
         n1 = self.gdb.nodes.create(name="Brian", place="AC/DC")
         index = self.gdb.nodes.indexes.create(name="doe")
@@ -1120,6 +1135,32 @@ class TransactionsTestCase(ExtensionsTestCase):
 #        #a non-transactional traversal will be 1 node short
 #        self.assertEqual(len(traversal), len(nodes))
 
+    def test_transaction_create_nodes_relationship(self):
+        TAG_DICT = {}
+        EDGE_DICT = {}
+        id1 = 1001
+        id2 = 1002
+        TAG_DICT[id1] = self.gdb.node.create(tag="tag1")
+        TAG_DICT[id2] = self.gdb.node.create(tag="tag2")
+        if not (id1, id2) in EDGE_DICT:
+            with self.gdb.transaction():
+                edge = self.gdb.node(name='EDGE_%04d_%04d' % (id1, id2),
+                                     type='edge', tag1=id1, tag2=id2)
+                tag1 = TAG_DICT[id1]
+                tag2 = TAG_DICT[id2]
+                edge.relationships.create("EDGE_TAG", tag1)
+                edge.relationships.create("EDGE_TAG", tag2)
+                RUN.relationships.create("RUN_EDGE", edge)
+                EDGE_DICT[(id1,id2)] = edge
+        else:
+            edge = EDGE_DICT[(id1,id2)]
+
+    def test_transaction_access_node(self):
+        frame = self.gdb.node.create()
+        with self.gdb.transaction():
+            edge = self.gdb.node(name='EDGE')
+        frame.FRAME_EDGE(edge)
+
 
 class PickleTestCase(TransactionsTestCase):
 
